@@ -6,69 +6,69 @@
 
 #include "browserwidget.h"
 
+#include "akonadibrowsermodel.h"
+#include "collectionaclpage.h"
 #include "collectionattributespage.h"
 #include "collectioninternalspage.h"
-#include "collectionaclpage.h"
-#include "dbaccess.h"
-#include "akonadibrowsermodel.h"
-#include "tagpropertiesdialog.h"
 #include "config-akonadiconsole.h"
+#include "dbaccess.h"
+#include "tagpropertiesdialog.h"
 
+#include <AkonadiCore/TagFetchScope>
 #include <AkonadiCore/attributefactory.h>
 #include <AkonadiCore/changerecorder.h>
-#include <AkonadiWidgets/controlgui.h>
+#include <AkonadiCore/collectionfilterproxymodel.h>
 #include <AkonadiCore/entitymimetypefiltermodel.h>
+#include <AkonadiCore/favoritecollectionsmodel.h>
 #include <AkonadiCore/itemfetchjob.h>
 #include <AkonadiCore/itemfetchscope.h>
 #include <AkonadiCore/itemmodifyjob.h>
 #include <AkonadiCore/job.h>
-#include <AkonadiCore/collectionfilterproxymodel.h>
-#include <AkonadiWidgets/collectionpropertiesdialog.h>
 #include <AkonadiCore/selectionproxymodel.h>
 #include <AkonadiCore/session.h>
-#include <AkonadiWidgets/standardactionmanager.h>
-#include <AkonadiWidgets/entitylistview.h>
-#include <AkonadiWidgets/entitytreeview.h>
-#include <AkonadiCore/favoritecollectionsmodel.h>
-#include <AkonadiCore/tagmodel.h>
 #include <AkonadiCore/statisticsproxymodel.h>
 #include <AkonadiCore/tagdeletejob.h>
-#include <AkonadiCore/TagFetchScope>
+#include <AkonadiCore/tagmodel.h>
+#include <AkonadiWidgets/collectionpropertiesdialog.h>
+#include <AkonadiWidgets/controlgui.h>
+#include <AkonadiWidgets/entitylistview.h>
+#include <AkonadiWidgets/entitytreeview.h>
+#include <AkonadiWidgets/standardactionmanager.h>
 #include <AkonadiXml/XmlWriteJob>
 #include <KViewStateMaintainer>
 #include <akonadi/private/compressionstream_p.h>
 
+#include <KCalendarCore/ICalFormat>
+#include <KCalendarCore/Incidence>
 #include <kcontacts/addressee.h>
 #include <kcontacts/contactgroup.h>
-#include <KCalendarCore/Incidence>
-#include <KCalendarCore/ICalFormat>
 
 #include "akonadiconsole_debug.h"
+#include <AkonadiCore/tagcreatejob.h>
+#include <AkonadiCore/tagmodifyjob.h>
+#include <KActionCollection>
 #include <KConfig>
 #include <KConfigGroup>
 #include <KMessageBox>
-#include <KXmlGuiWindow>
 #include <KToggleAction>
-#include <KActionCollection>
-#include <AkonadiCore/tagmodifyjob.h>
-#include <AkonadiCore/tagcreatejob.h>
+#include <KXmlGuiWindow>
 
-#include <QSplitter>
-#include <QVBoxLayout>
-#include <QStandardItemModel>
-#include <QSqlQuery>
-#include <QTimer>
 #include <KSharedConfig>
-#include <QMenu>
-#include <QFileDialog>
-#include <QSqlError>
 #include <QBuffer>
+#include <QFileDialog>
+#include <QMenu>
+#include <QSplitter>
+#include <QSqlError>
+#include <QSqlQuery>
+#include <QStandardItemModel>
+#include <QTimer>
+#include <QVBoxLayout>
 
 #ifdef ENABLE_CONTENTVIEWS
+#include <Akonadi/Contact/ContactGroupViewer>
+#include <Akonadi/Contact/ContactViewer>
 #include <CalendarSupport/IncidenceViewer>
 #include <MessageViewer/Viewer>
-#include <Akonadi/Contact/ContactViewer>
-#include <Akonadi/Contact/ContactGroupViewer>
 #endif
 
 using namespace Akonadi;
@@ -83,13 +83,13 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     : QWidget(parent)
 {
     Q_ASSERT(xmlGuiWindow);
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
-    auto *splitter = new QSplitter(Qt::Horizontal, this);
+    auto splitter = new QSplitter(Qt::Horizontal, this);
     splitter->setObjectName(QStringLiteral("collectionSplitter"));
     layout->addWidget(splitter);
 
-    auto *splitter2 = new QSplitter(Qt::Vertical, this);
+    auto splitter2 = new QSplitter(Qt::Vertical, this);
     splitter2->setObjectName(QStringLiteral("ffvSplitter"));
 
     mCollectionView = new Akonadi::EntityTreeView(xmlGuiWindow, this);
@@ -97,13 +97,13 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     mCollectionView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     splitter2->addWidget(mCollectionView);
 
-    auto *favoritesView = new EntityListView(xmlGuiWindow, this);
-    //favoritesView->setViewMode( QListView::IconMode );
+    auto favoritesView = new EntityListView(xmlGuiWindow, this);
+    // favoritesView->setViewMode( QListView::IconMode );
     splitter2->addWidget(favoritesView);
 
     splitter->addWidget(splitter2);
 
-    auto *tagRecorder = new ChangeRecorder(this);
+    auto tagRecorder = new ChangeRecorder(this);
     tagRecorder->setObjectName(QStringLiteral("tagRecorder"));
     tagRecorder->setTypeMonitored(Monitor::Tags);
     tagRecorder->setChangeRecordingEnabled(false);
@@ -135,9 +135,9 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     mBrowserModel->setShowSystemEntities(true);
     mBrowserModel->setListFilter(CollectionFetchScope::Display);
 
-//   new ModelTest( mBrowserModel );
+    //   new ModelTest( mBrowserModel );
 
-    auto *collectionFilter = new EntityMimeTypeFilterModel(this);
+    auto collectionFilter = new EntityMimeTypeFilterModel(this);
     collectionFilter->setSourceModel(mBrowserModel);
     collectionFilter->addMimeTypeInclusionFilter(Collection::mimeType());
     collectionFilter->setHeaderGroup(EntityTreeModel::CollectionTreeHeaders);
@@ -150,28 +150,28 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
 
     mCollectionView->setModel(statisticsProxyModel);
 
-    auto *selectionProxyModel = new Akonadi::SelectionProxyModel(mCollectionView->selectionModel(), this);
+    auto selectionProxyModel = new Akonadi::SelectionProxyModel(mCollectionView->selectionModel(), this);
     selectionProxyModel->setSourceModel(mBrowserModel);
     selectionProxyModel->setFilterBehavior(KSelectionProxyModel::ChildrenOfExactSelection);
 
-    auto *itemFilter = new EntityMimeTypeFilterModel(this);
+    auto itemFilter = new EntityMimeTypeFilterModel(this);
     itemFilter->setSourceModel(selectionProxyModel);
     itemFilter->addMimeTypeExclusionFilter(Collection::mimeType());
     itemFilter->setHeaderGroup(EntityTreeModel::ItemListHeaders);
 
     const KConfigGroup group = KSharedConfig::openConfig()->group("FavoriteCollectionsModel");
     connect(mBrowserModel, &AkonadiBrowserModel::columnsChanged, itemFilter, &EntityMimeTypeFilterModel::invalidate);
-    auto *sortModel = new AkonadiBrowserSortModel(mBrowserModel, this);
+    auto sortModel = new AkonadiBrowserSortModel(mBrowserModel, this);
     sortModel->setDynamicSortFilter(true);
     sortModel->setSourceModel(itemFilter);
-    auto *favoritesModel = new FavoriteCollectionsModel(mBrowserModel, group, this);
+    auto favoritesModel = new FavoriteCollectionsModel(mBrowserModel, group, this);
     favoritesView->setModel(favoritesModel);
 
-    auto *splitter3 = new QSplitter(Qt::Vertical, this);
+    auto splitter3 = new QSplitter(Qt::Vertical, this);
     splitter3->setObjectName(QStringLiteral("itemSplitter"));
     splitter->addWidget(splitter3);
 
-    auto *itemViewParent = new QWidget(this);
+    auto itemViewParent = new QWidget(this);
     itemUi.setupUi(itemViewParent);
 
     itemUi.modelBox->addItem(QStringLiteral("Generic"));
@@ -189,7 +189,7 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget *parent)
     splitter3->addWidget(itemViewParent);
     itemViewParent->layout()->setContentsMargins(0, 0, 0, 0);
 
-    auto *contentViewParent = new QWidget(this);
+    auto contentViewParent = new QWidget(this);
     contentUi.setupUi(contentViewParent);
     contentUi.saveButton->setEnabled(false);
     connect(contentUi.saveButton, &QPushButton::clicked, this, &BrowserWidget::save);
@@ -271,13 +271,13 @@ void BrowserWidget::clear()
 
 void BrowserWidget::currentChanged(const QModelIndex &index)
 {
-    const Item item = index.sibling(index.row(), 0).data(EntityTreeModel::ItemRole).value< Item >();
+    const Item item = index.sibling(index.row(), 0).data(EntityTreeModel::ItemRole).value<Item>();
     if (!item.isValid()) {
         clear();
         return;
     }
 
-    auto *job = new ItemFetchJob(item, this);
+    auto job = new ItemFetchJob(item, this);
     job->fetchScope().fetchFullPayload();
     job->fetchScope().fetchAllAttributes();
     job->fetchScope().setFetchTags(true);
@@ -289,7 +289,7 @@ void BrowserWidget::currentChanged(const QModelIndex &index)
 
 void BrowserWidget::itemFetchDone(KJob *job)
 {
-    auto *fetch = static_cast<ItemFetchJob *>(job);
+    auto fetch = static_cast<ItemFetchJob *>(job);
     if (job->error()) {
         qCWarning(AKONADICONSOLE_LOG) << "Item fetch failed: " << job->errorString();
     } else if (fetch->items().isEmpty()) {
@@ -318,13 +318,12 @@ void BrowserWidget::setItem(const Akonadi::Item &item)
     } else if (item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
         mIncidenceView->setItem(item);
         contentUi.stack->setCurrentWidget(mIncidenceView->parentWidget());
-    } else if (item.mimeType() == QLatin1String("message/rfc822")
-               || item.mimeType() == QLatin1String("message/news")) {
+    } else if (item.mimeType() == QLatin1String("message/rfc822") || item.mimeType() == QLatin1String("message/news")) {
         mMailView->setMessageItem(item, MimeTreeParser::Force);
         contentUi.stack->setCurrentWidget(mMailView->parentWidget());
     } else
 #endif
-    if (item.hasPayload<QPixmap>()) {
+        if (item.hasPayload<QPixmap>()) {
         contentUi.imageView->setPixmap(item.payload<QPixmap>());
         contentUi.stack->setCurrentWidget(contentUi.imageViewPage);
     } else {
@@ -394,14 +393,14 @@ void BrowserWidget::setItem(const Akonadi::Item &item)
     connect(mAttrModel, &QStandardItemModel::itemChanged, this, &BrowserWidget::contentViewChanged);
 
     if (mMonitor) {
-        mMonitor->deleteLater();    // might be the one calling us
+        mMonitor->deleteLater(); // might be the one calling us
     }
     mMonitor = new Monitor(this);
     mMonitor->setObjectName(QStringLiteral("itemMonitor"));
     mMonitor->setItemMonitored(item);
     mMonitor->itemFetchScope().fetchFullPayload();
     mMonitor->itemFetchScope().fetchAllAttributes();
-    qRegisterMetaType<QSet<QByteArray> >();
+    qRegisterMetaType<QSet<QByteArray>>();
     connect(mMonitor, &Akonadi::Monitor::itemChanged, this, &BrowserWidget::setItem, Qt::QueuedConnection);
     contentUi.saveButton->setEnabled(false);
 }
@@ -463,7 +462,7 @@ void BrowserWidget::save()
         item.addAttribute(attr);
     }
 
-    auto *store = new ItemModifyJob(item, this);
+    auto store = new ItemModifyJob(item, this);
     connect(store, &ItemModifyJob::result, this, &BrowserWidget::saveResult);
 }
 
@@ -514,7 +513,7 @@ void BrowserWidget::dumpToXml()
         return;
     }
 
-    auto *job = new XmlWriteJob(root, fileName, this);
+    auto job = new XmlWriteJob(root, fileName, this);
     connect(job, &XmlWriteJob::result, this, &BrowserWidget::dumpToXmlResult);
 }
 
@@ -543,12 +542,15 @@ void BrowserWidget::clearCache()
     query.next();
     const int emptyRidCount = query.value(0).toInt();
     if (emptyRidCount > 0) {
-        if (KMessageBox::warningContinueCancel(this, QStringLiteral(
-                                                   "The collection '%1' contains %2 items without Remote ID. "
-                                                   "Those items were likely never uploaded to the destination server, "
-                                                   "so clearing this collection means that those <b>data will be lost</b>. "
-                                                   "Are you sure you want to proceed?").arg(coll.id()).arg(emptyRidCount),
-                                               QStringLiteral("POSSIBLE DATA LOSS!")) == KMessageBox::Cancel) {
+        if (KMessageBox::warningContinueCancel(this,
+                                               QStringLiteral("The collection '%1' contains %2 items without Remote ID. "
+                                                              "Those items were likely never uploaded to the destination server, "
+                                                              "so clearing this collection means that those <b>data will be lost</b>. "
+                                                              "Are you sure you want to proceed?")
+                                                   .arg(coll.id())
+                                                   .arg(emptyRidCount),
+                                               QStringLiteral("POSSIBLE DATA LOSS!"))
+            == KMessageBox::Cancel) {
             return;
         }
     }
@@ -585,13 +587,21 @@ void BrowserWidget::updateItemFetchScope()
 void BrowserWidget::tagViewContextMenuRequested(const QPoint &pos)
 {
     const QModelIndex index = mTagView->indexAt(pos);
-    auto *menu = new QMenu(this);
+    auto menu = new QMenu(this);
     connect(menu, &QMenu::aboutToHide, menu, &QMenu::deleteLater);
     menu->addAction(QIcon::fromTheme(QStringLiteral("list-add")), QStringLiteral("&Add tag..."), this, &BrowserWidget::addTagRequested);
     if (index.isValid()) {
         menu->addAction(QStringLiteral("Add &subtag..."), this, &BrowserWidget::addSubTagRequested);
-        menu->addAction(QIcon::fromTheme(QStringLiteral("document-edit")), QStringLiteral("&Edit tag..."), this, &BrowserWidget::editTagRequested, QKeySequence(Qt::Key_Return));
-        menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), QStringLiteral("&Delete tag..."), this, &BrowserWidget::removeTagRequested, QKeySequence::Delete);
+        menu->addAction(QIcon::fromTheme(QStringLiteral("document-edit")),
+                        QStringLiteral("&Edit tag..."),
+                        this,
+                        &BrowserWidget::editTagRequested,
+                        QKeySequence(Qt::Key_Return));
+        menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
+                        QStringLiteral("&Delete tag..."),
+                        this,
+                        &BrowserWidget::removeTagRequested,
+                        QKeySequence::Delete);
         menu->setProperty("Tag", index.data(TagModel::TagRole));
     }
 
@@ -600,7 +610,7 @@ void BrowserWidget::tagViewContextMenuRequested(const QPoint &pos)
 
 void BrowserWidget::addTagRequested()
 {
-    auto *dlg = new TagPropertiesDialog(this);
+    auto dlg = new TagPropertiesDialog(this);
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::createTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -608,13 +618,13 @@ void BrowserWidget::addTagRequested()
 
 void BrowserWidget::addSubTagRequested()
 {
-    auto *action = qobject_cast<QAction *>(sender());
+    auto action = qobject_cast<QAction *>(sender());
     const Akonadi::Tag parentTag = action->parent()->property("Tag").value<Akonadi::Tag>();
 
     Akonadi::Tag tag;
     tag.setParent(parentTag);
 
-    auto *dlg = new TagPropertiesDialog(tag, this);
+    auto dlg = new TagPropertiesDialog(tag, this);
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::createTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -622,9 +632,9 @@ void BrowserWidget::addSubTagRequested()
 
 void BrowserWidget::editTagRequested()
 {
-    auto *action = qobject_cast<QAction *>(sender());
+    auto action = qobject_cast<QAction *>(sender());
     const Akonadi::Tag tag = action->parent()->property("Tag").value<Akonadi::Tag>();
-    auto *dlg = new TagPropertiesDialog(tag, this);
+    auto dlg = new TagPropertiesDialog(tag, this);
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::modifyTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -640,7 +650,7 @@ void BrowserWidget::tagViewDoubleClicked(const QModelIndex &index)
     const Akonadi::Tag tag = mTagModel->data(index, TagModel::TagRole).value<Akonadi::Tag>();
     Q_ASSERT(tag.isValid());
 
-    auto *dlg = new TagPropertiesDialog(tag, this);
+    auto dlg = new TagPropertiesDialog(tag, this);
     connect(dlg, &TagPropertiesDialog::accepted, this, &BrowserWidget::modifyTag);
     connect(dlg, &TagPropertiesDialog::rejected, dlg, &TagPropertiesDialog::deleteLater);
     dlg->show();
@@ -648,20 +658,25 @@ void BrowserWidget::tagViewDoubleClicked(const QModelIndex &index)
 
 void BrowserWidget::removeTagRequested()
 {
-    if (KMessageBox::questionYesNo(this, QStringLiteral("Do you really want to remove selected tag?"),
-                                   QStringLiteral("Delete tag?"), KStandardGuiItem::del(), KStandardGuiItem::cancel(),
-                                   QString(), KMessageBox::Dangerous) == KMessageBox::No) {
+    if (KMessageBox::questionYesNo(this,
+                                   QStringLiteral("Do you really want to remove selected tag?"),
+                                   QStringLiteral("Delete tag?"),
+                                   KStandardGuiItem::del(),
+                                   KStandardGuiItem::cancel(),
+                                   QString(),
+                                   KMessageBox::Dangerous)
+        == KMessageBox::No) {
         return;
     }
 
-    auto *action = qobject_cast<QAction *>(sender());
+    auto action = qobject_cast<QAction *>(sender());
     const Akonadi::Tag tag = action->parent()->property("Tag").value<Akonadi::Tag>();
     new Akonadi::TagDeleteJob(tag, this);
 }
 
 void BrowserWidget::createTag()
 {
-    auto *dlg = qobject_cast<TagPropertiesDialog *>(sender());
+    auto dlg = qobject_cast<TagPropertiesDialog *>(sender());
     Q_ASSERT(dlg);
 
     if (dlg->changed()) {
@@ -671,7 +686,7 @@ void BrowserWidget::createTag()
 
 void BrowserWidget::modifyTag()
 {
-    auto *dlg = qobject_cast<TagPropertiesDialog *>(sender());
+    auto dlg = qobject_cast<TagPropertiesDialog *>(sender());
     Q_ASSERT(dlg);
 
     if (dlg->changed()) {
