@@ -8,27 +8,27 @@
 
 #include "debugwidget.h"
 
-#include "tracernotificationinterface.h"
 #include "connectionpage.h"
+#include "tracernotificationinterface.h"
 
 #include <AkonadiWidgets/controlgui.h>
 
-#include <QTabWidget>
-#include <KTextEdit>
 #include <AkonadiCore/ServerManager>
+#include <KTextEdit>
+#include <QTabWidget>
 
+#include <QCheckBox>
+#include <QFileDialog>
 #include <QPushButton>
 #include <QSplitter>
 #include <QVBoxLayout>
-#include <QCheckBox>
-#include <QFileDialog>
 
 using org::freedesktop::Akonadi::DebugInterface;
 
 DebugWidget::DebugWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
     QString service = QStringLiteral("org.freedesktop.Akonadi");
     if (Akonadi::ServerManager::hasInstanceIdentifier()) {
@@ -40,7 +40,7 @@ DebugWidget::DebugWidget(QWidget *parent)
     connect(cb, &QCheckBox::toggled, this, &DebugWidget::enableDebugger);
     layout->addWidget(cb);
 
-    auto *splitter = new QSplitter(Qt::Vertical, this);
+    auto splitter = new QSplitter(Qt::Vertical, this);
     splitter->setObjectName(QStringLiteral("debugSplitter"));
     layout->addWidget(splitter);
 
@@ -50,13 +50,14 @@ DebugWidget::DebugWidget(QWidget *parent)
     mGeneralView = new KTextEdit(splitter);
     mGeneralView->setReadOnly(true);
 
-    org::freedesktop::Akonadi::TracerNotification *iface = new org::freedesktop::Akonadi::TracerNotification(QString(), QStringLiteral("/tracing/notifications"), QDBusConnection::sessionBus(), this);
+    org::freedesktop::Akonadi::TracerNotification *iface =
+        new org::freedesktop::Akonadi::TracerNotification(QString(), QStringLiteral("/tracing/notifications"), QDBusConnection::sessionBus(), this);
 
     connect(iface, &org::freedesktop::Akonadi::TracerNotification::signalEmitted, this, &DebugWidget::signalEmitted);
     connect(iface, &org::freedesktop::Akonadi::TracerNotification::warningEmitted, this, &DebugWidget::warningEmitted);
     connect(iface, &org::freedesktop::Akonadi::TracerNotification::errorEmitted, this, &DebugWidget::errorEmitted);
 
-    auto *buttonLayout = new QHBoxLayout;
+    auto buttonLayout = new QHBoxLayout;
     layout->addLayout(buttonLayout);
 
     QPushButton *clearGeneralButton = new QPushButton(QStringLiteral("Clear Information View"), this);
